

; Common Emacs configuration

; Just for convenience

(require 'dired-x)
(require 'saveplace)
(setq-default save-place t)
(auto-compression-mode t)
(setq-default transient-mark-mode       t)
(setq make-backup-files nil)
(setq search-highlight                  t)

;; For Emacspeak
(setq-default emacspeak-use-auditory-icons t)

;;; Key customizations.
(global-set-key "\C-xg" 'goto-line)
(global-set-key "\C-xy" 'insert-register)
(global-set-key [home] 'beginning-of-line)
(global-set-key [end] 'end-of-line)
(global-set-key [?\e home] 'beginning-of-buffer)
(global-set-key [?\e end] 'end-of-buffer)
(global-set-key [f1] 'shell)
(global-set-key [f2] 'save-buffer)
(global-set-key [f3] 'find-file)
(fset 'macro-123
   [?\C-[ ?! ?\304 ?\321 ?\304 ?\321 ?  ?\327 ?\301 ?\323 ?\321 ?\C-m])
(global-set-key [-134217637 112 f3] 'macro-123)
(global-set-key [f5] 'other-window)
(global-set-key [f8] 'kill-buffer)
(global-set-key [f12] 'rbook-read-here)
(fset 'macro-replace
   [?\M-x ?r ?e ?p ?l ?a ?c ?e ?- ?s ?t ?r ?i ?n ?g return ?\C-q ?4 ?2 ?5 ?3 return return return return insert home ?\M-x up return ?\C-q ?4 ?2 ?7 ?3 return return return return insert home ?\M-x up return ?\C-q ?1 ?2 ?3 ?4 ?5 ?6 ?3 return return return return insert home ?\M-x up return ?\C-q ?1 ?2 ?3 ?4 ?6 ?4 ?6 return return return return])
(global-set-key [f6 f12] 'macro-replace)
(push "/usr/local/share/emacs/site-lisp/rbook" load-path)
(load "rbook-init" t)
(global-set-key [f14] 'buffer-menu)
(global-set-key [f15] 'find-name-dired)
(global-set-key [f17] 'find-grep-dired)
(global-set-key [f18] 'delete-window)
(global-set-key [f19] 'compile)
(global-set-key [f20] 'tmm-menubar)
(global-set-key [?\e f7] 'find-name-dired)

;; Unbind C-z to shell instead of suspend-emacs (it is too easy to press C-z and hence suspending Emacspeak).
;; Rather use C-z C-z to suspend emacs
(global-unset-key "\C-z")
(global-unset-key "\C-x\C-z")
(global-set-key "\C-z\C-z" 'suspend-emacs)

; Compilation process
(setq compilation-ask-about-save        nil)
(setq compile-command "make -ks ")

;;; The following color settings will work well only if the
;;; default background color is lightgray!
(set-face-background 'default          "black")
(set-face-foreground 'default           "cyan")
(set-face-background 'modeline          "blue")
(set-face-foreground 'modeline          "white")
(set-face-background 'region            "magenta")
(set-face-foreground 'region            "yellow")

;;; Font-locking faces set-up
;
;; Switch on font-lock for every mode which supports it.
(if (fboundp 'global-font-lock-mode)
    (global-font-lock-mode t)
  (add-hook 'find-file-hooks 'turn-on-font-lock))
;
;;; Each element of the list should be of the form

;;;    (FACE FOREGROUND BACKGROUND BOLD-P ITALIC-P UNDERLINE-P)

;;; where FACE should be one of the face symbols, and the subsequent element
;;; items should be the attributes for the corresponding Font Lock mode
;;; faces.  Attributes FOREGROUND and BACKGROUND should be strings (default
;;; if nil), while BOLD-P, ITALIC-P, and UNDERLINE-P should specify the
;;; corresponding face attributes (yes if non-nil).
;;;
(setq font-lock-face-attributes
      '((font-lock-comment-face "red" nil nil t nil)
        (font-lock-string-face "brown" nil nil t nil)
        (font-lock-keyword-face "magenta" nil t nil nil)
        (font-lock-type-face "lightgreen" nil nil nil nil)
        (font-lock-function-name-face "lightred" nil t nil nil)
        (font-lock-variable-name-face "yellow" nil nil nil nil)
        (font-lock-reference-face "lightred" nil nil nil t)))
;
(setq font-lock-maximum-decoration t)
(setq font-lock-maximum-size
      (if font-lock-maximum-decoration (* 70 1024) (* 150 1024)))
;
;; This fontifies the compilation buffer when compilation exits.
(defun my-compilation-finish-function (buf msg)
  "This is called after the compilation exits.  Currently just
highlights the compilation messages."
  (save-excursion
    (set-buffer buf)
    (font-lock-fontify-buffer)))
(setq compilation-finish-function 'my-compilation-finish-function)
;
;; Setting this to t makes scrolling faster, but may momentarily present
;; unfontified areas when you scroll into them.
(setq lazy-lock-defer-on-scrolling t)
;
;; Lazy-lock setup
(autoload 'turn-on-lazy-lock "lazy-lock"
  "Unconditionally turn on Lazy Lock mode.")
(add-hook 'font-lock-mode-hook 'turn-on-lazy-lock)
(setq lazy-lock-minimum-size (* 4 1024))
(setq lazy-lock-stealth-time 16)
(setq lazy-lock-defer-time 0.15)
(setq lazy-lock-stealth-nice 1)
(setq lazy-lock-stealth-lines 60)
(setq font-lock-maximum-size nil)  ; appropriate with lazy-lock

;;; Display the time on modeline
(display-time)

;;; This is to not display the initial message (which says to a novice
;;; user what to do first if he/she is confused).
(setq inhibit-startup-message t)

;;; This disables down-arrow and C-n at the end of a buffer from adding
;;; a new line to that buffer.
(setq next-line-add-newlines nil)

;;; This makes `apropos' and `super-apropos' do everything that they can.
;;; Makes them run 2 or 3 times slower.  Set this non-nil if you have a
;;; fast machine.
(setq apropos-do-all t)
;
;;; CC-Mode stuff, customizes C/C++/ObjC language support.
(setq auto-mode-alist
  (append '(("\\.CC$"  . c++-mode)
            ("\\.cc$" . c++-mode)
            ("\\.cpp$" . c++-mode)
            ("\\.cxx$" . c++-mode)
            ("\\.hpp$" . c++-mode)
            ("\\.hxx$" . c++-mode)
            ("\\.hh$" . c++-mode)
            ("\\.c$"  . c-mode)   ; to edit C code
            ("\\.h$"  . c-mode)   ; to edit C code
            ("\\.m$"  . objc-mode); to edit ObjC code
           ) auto-mode-alist))
;
;;; Automatic online help for library functions
(autoload 'find-tag-tag "etags")
(autoload 'Info-find-node "info")
(defun libc-help (arg)
  (interactive (list (find-tag-tag "C library topic: ")))
  (Info-find-node "libc" arg))
;
(defun my-c-stuff ()
    "My own C stuff.  Swaps RET and LFD (^J) and customizes
indentation style and dynamic abbrevs."
    (modify-syntax-entry ?_ "w")
    (c-set-offset 'case-label '+)
    (c-set-offset 'brace-list-open '+)
    (setq c-electric-pound-behavior '(alignleft))
    (setq c-progress-interval 2) ;; or else I tend to think it crashed
    (setq c-macro-shrink-window-flag t)
    (setq c-macro-prompt-flag t)
    (set (make-local-variable 'dabbrev-case-fold-search) nil)
    (set (make-local-variable 'dabbrev-case-replace) nil)
    (define-key c-mode-map [C-f1] 'libc-help)
    (define-key c-mode-map "\C-c %" 'match-paren)
    (define-key c-mode-map "\C-j" 'newline)
    (define-key c-mode-map "\C-m" 'newline-and-indent))
(add-hook 'c-mode-common-hook 'my-c-stuff)

(defun my-textmode-stuff ()
  "My own Text-Mode routine. Customizes dynamic abbrevs."
  (set (make-local-variable 'dabbrev-case-fold-search) t)
  (set (make-local-variable 'dabbrev-case-replace) t)
  (set (make-local-variable 'dabbrev-upcase-means-case-search) t))
(add-hook 'text-mode-hook 'turn-on-auto-fill)
(add-hook 'text-mode-hook 'my-textmode-stuff)

(defun my-elisp-stuff ()
  "My own Emacs Lisp stuff.  Currently remaps ^J and ^M and customizes
dynamic abbrevs."
  (set (make-local-variable 'dabbrev-case-fold-search) nil)
  (set (make-local-variable 'dabbrev-case-replace) nil)
  (define-key emacs-lisp-mode-map "\C-j" 'newline)
  (define-key emacs-lisp-mode-map "\C-m" 'newline-and-indent))
(add-hook 'emacs-lisp-mode-hook 'my-elisp-stuff)
(defun my-info-stuff ()
  "My own Info stuff.  Currently sets faces and some variables."
    (set-face-foreground 'info-xref     "yellow")
    (set-face-background 'info-xref     "lightgray")
    (set-face-foreground 'info-node     "lightred")
    (set-face-background 'info-node     "lightgray")
    (setq automatic-footnotes "On"))
(add-hook 'Info-mode-hook 'my-info-stuff)
(setq auto-mode-alist
      (append '(("\\.txh$"  . texinfo-mode))
              auto-mode-alist))
(defun my-texinfo-stuff ()
  "My own Texinfo mode customizations."
  (set (make-local-variable 'dabbrev-case-fold-search) nil)
  (set (make-local-variable 'dabbrev-case-replace) nil)
  (define-key texinfo-mode-map [f9] 'makeinfo-buffer)
  (define-key texinfo-mode-map [\C-f9] 'makeinfo-region)
  (define-key emacs-lisp-mode-map "\C-j" 'newline)
  (define-key emacs-lisp-mode-map "\C-m" 'newline-and-indent))
(add-hook 'texinfo-mode-hook 'my-texinfo-stuff)

;;; Automatically makes the matching paren stand out in color.
(condition-case err
    (show-paren-mode t)
  (error
   (message "Cannot show parens %s" (cdr err))))

;;; This moves the mouse pointer out of my way when I type.
(condition-case err
    (mouse-avoidance-mode 'banish)
  (error
   (message "Cannot use mouse-avoid %s" (cdr err))))

;;; Enable some commands we need.
(put 'narrow-to-region 'disabled nil)
(put 'downcase-region 'disabled nil)
(put 'upcase-region 'disabled nil)

;; Language environment
(cond
 ((string-match "ru" (getenv "LANG"))
;;  (set-language-environment 'utf-8)
  (set-input-mode (car (current-input-mode))
		  (nth 1 (current-input-mode))
		  0)
  (codepage-setup 1251)
  (define-coding-system-alias 'windows-1251 'cp1251)
  (set-terminal-coding-system 'utf-8)
  (set-keyboard-coding-system 'utf-8)
  (setq default-buffer-file-coding-system 'utf-8)
  (set-case-syntax-pair 224 192 (standard-case-table))
  (set-case-syntax-pair 225 193 (standard-case-table))
  (set-case-syntax-pair 226 194 (standard-case-table))
  (set-case-syntax-pair 227 195 (standard-case-table))
  (set-case-syntax-pair 228 196 (standard-case-table))
  (set-case-syntax-pair 229 197 (standard-case-table))
  (set-case-syntax-pair 230 198 (standard-case-table))
  (set-case-syntax-pair 231 199 (standard-case-table))
  (set-case-syntax-pair 232 200 (standard-case-table))
  (set-case-syntax-pair 233 201 (standard-case-table))
  (set-case-syntax-pair 234 202 (standard-case-table))
  (set-case-syntax-pair 235 203 (standard-case-table))
  (set-case-syntax-pair 236 204 (standard-case-table))
  (set-case-syntax-pair 237 205 (standard-case-table))
  (set-case-syntax-pair 238 206 (standard-case-table))
  (set-case-syntax-pair 239 207 (standard-case-table))
  (set-case-syntax-pair 240 208 (standard-case-table))
  (set-case-syntax-pair 241 209 (standard-case-table))
  (set-case-syntax-pair 242 210 (standard-case-table))
  (set-case-syntax-pair 243 211 (standard-case-table))
  (set-case-syntax-pair 244 212 (standard-case-table))
  (set-case-syntax-pair 245 213 (standard-case-table))
  (set-case-syntax-pair 246 214 (standard-case-table))
  (set-case-syntax-pair 247 215 (standard-case-table))
  (set-case-syntax-pair 248 216 (standard-case-table))
  (set-case-syntax-pair 249 217 (standard-case-table))
  (set-case-syntax-pair 250 218 (standard-case-table))
  (set-case-syntax-pair 251 219 (standard-case-table))
  (set-case-syntax-pair 252 220 (standard-case-table))
  (set-case-syntax-pair 253 221 (standard-case-table))
  (set-case-syntax-pair 254 222 (standard-case-table))
  (set-case-syntax-pair 255 223 (standard-case-table))
  (set-case-syntax-pair 179 163 (standard-case-table))
  (print "Russian environment"))
 (t 
  (set-language-environment 'latin-1)
  (set-terminal-coding-system 'latin-1)
  (set-keyboard-coding-system 'iso-latin-1)
  (setq default-buffer-file-coding-system 'iso-latin-1)
  (print "Latin-1 environment")))


;; Debian specific tools menu and hotkeys
(when (featurep 'debian-el)
  (global-set-key [?\e f3] 'debian-bug)
  (global-set-key [?\e f4] 'apt-utils-show-package)
  (global-set-key [?\e f5] 'apt-utils-search)
  (setq debian-menu (make-sparse-keymap "DEBIAN"))
  (define-key global-map [menu-bar tools DEBIAN]
    (cons "Debian" debian-menu))
  (define-key global-map [menu-bar tools DEBIAN reportbug]
    '("Send bug report" . debian-bug))
  (define-key global-map [menu-bar tools DEBIAN aptsearch]
    '("Search package" . apt-utils-search))
  (define-key global-map [menu-bar tools DEBIAN aptshow]
    '("Show package info" . apt-utils-show-package))
  (when (featurep 'emacspeak)
    ;; Do not be too quiet.
    (defadvice debian-bug (around emacspeak pre act comp)
      "Provide speech feedback."
      (let ((emacspeak-speak-messages t))
	ad-do-it))))


;; Start emacs-server
(server-start)

;; Readiness notification
(when (featurep 'emacspeak)
  (emacspeak-auditory-icon 'on))


;;makros
(autoload 'mpg123 "mpg123" "A Front-end to mpg123" t)
(global-set-key [insert] nil)
;;звуковые сообщения
(fset 'macro-time
   "\C-[!tim\C-m")
(global-set-key [f9] 'macro-time)
;;сообщить дату
(fset 'macro-data
   "\C-[!data\C-m")
(global-set-key [insertchar 100] 'macro-data)
(global-set-key [insert 100] 'macro-data)
(fset 'macro-ins-data
   [?\C-[ ?! ?s ?t ?u ?\C-? ?\C-? ?\C-? ?\323 ?\305 ?\307 ?\317 ?\304 ?\316 ?\321 ?\333 ?\316 ?\321 ?\321 ?  ?\304 ?\301 ?\324 ?\301 ?\C-m])
(global-set-key [-134217637 112 insertchar ?d] 'macro-ins-data)
(global-set-key [-134217637 112 insert ?d] 'macro-ins-data)

;;навигатор
;;вызов файла помощи
(fset 'macro-help
"\C-[xfind-file\C-m/etc/script/help\C-m")
(global-set-key [insertchar ?h] 'macro-help)
(global-set-key [insert ?h] 'macro-help)
(fset 'macro-ins-h
   [?\C-[ ?! ?\306 ?\301 ?\312 ?\314 ?  ?\320 ?\317 ?\315 ?\317 ?\335 ?\311 ?\C-m])
(global-set-key [-134217637 112 insertchar ?h] 'macro-ins-h)
(global-set-key [-134217637 112 insert ?h] 'macro-ins-h)
;;запуск xwindow
(fset 'macro-xwindow
   "\C-[!.X\C-m")
(global-set-key [insertchar ?X] 'macro-xwindow)
;;переход в предыдущий буфер
(fset 'macro-other-buffer
   "\C-[xswitch-to-buffer\C-m\C-m")
(global-set-key [insertchar f5] 'macro-other-buffer)
(global-set-key [insert f5] 'macro-other-buffer)
(fset 'macro-ins-f5
   [?\C-[ ?! ?\320 ?\305 ?\322 ?\305 ?\312 ?\324 ?\311 ?  ?\327 ?  ?\320 ?\322 ?\305 ?\304 ?\331 ?\304 ?\325 ?\335 ?\311 ?\312 ?  ?\302 ?\325 ?\306 ?\305 ?\322 ?\C-m])
(global-set-key [-134217637 112 insertchar f5] 'macro-ins-f5)
(global-set-key [-134217637 112 insert f5] 'macro-ins-f5)
;;переход в начало буффера
(global-set-key [insertchar home] 'beginning-of-buffer)
(global-set-key [insert home] 'beginning-of-buffer)
(fset 'macro-ins-home
   [?\C-[ ?! ?g ?\C-? ?\320 ?\305 ?\322 ?\305 ?\310 ?\317 ?\304 ?  ?\327 ?  ?\316 ?\301 ?\336 ?\301 ?\314 ?\317 ?  ?\302 ?\325 ?\306 ?\305 ?\322 ?\301 ?  ?\311 ?\314 ?\311 ?  ?\306 ?\301 ?\312 ?\314 ?\301 ?\C-m])
(global-set-key [-134217637 112 insertchar home] 'macro-ins-home)
(global-set-key [-134217637 112 insert home] 'macro-ins-home)
;;переход в конец файла
(global-set-key [insertchar end] 'end-of-buffer)
(global-set-key [insert end] 'end-of-buffer)
(fset 'macro-ins-end
   [?\C-[ ?! ?\320 ?\305 ?\322 ?\305 ?\310 ?\317 ?\304 ?  ?\327 ?  ?\313 ?\317 ?\316 ?\305 ?\303 ?  ?\302 ?\325 ?\306 ?\305 ?\322 ?\301 ?  ?\311 ?\314 ?\311 ?  ?\306 ?\301 ?\312 ?\314 ?\301 ?\C-m])
(global-set-key [-134217637 112 insertchar end] 'macro-ins-end)
(global-set-key [-134217637 112 insert end] 'macro-ins-end)
;;переход на следующий абзац
(global-set-key [insertchar down] 'forward-paragraph)
(global-set-key [insert down] 'forward-paragraph)
(fset 'macro-ins-down
   [?\C-[ ?! ?/ ?\C-? ?\320 ?\305 ?\322 ?\305 ?\310 ?\317 ?\304 ?  ?\316 ?\301 ?  ?\323 ?\314 ?\305 ?\304 ?\325 ?\300 ?\335 ?\311 ?\312 ?  ?\301 ?\302 ?\332 ?\301 ?\303 ?\C-m])
(global-set-key [-134217637 112 insertchar down] 'macro-ins-down)
(global-set-key [-134217637 112 insert down] 'macro-ins-down)
;;переход на предыдущий абзац
(global-set-key [insertchar up] 'backward-paragraph)
(global-set-key [insertchar prior] 'forward-sentence)
(global-set-key [insert up] 'backward-paragraph)
(global-set-key [insert prior] 'forward-sentence)
(fset 'macro-ins-up
   [?\C-[ ?! ?g ?\C-? ?\320 ?\305 ?\322 ?\305 ?\310 ?\317 ?\304 ?  ?\316 ?\301 ?  ?\320 ?\322 ?\305 ?\304 ?\331 ?\304 ?\325 ?\335 ?\311 ?\312 ?  ?\301 ?\302 ?\332 ?\301 ?\303 ?\C-m])
(global-set-key [-134217637 112 insertchar up] 'macro-ins-up)
(global-set-key [-134217637 112 insert up] 'macro-ins-up)
;;стереть файл или каталог
(fset 'macro-musor
   "\C-[xshell\C-m.del\C-m")
(global-set-key [insertchar ?k] 'macro-musor)
(global-set-key [insert ?k] 'macro-musor)
(fset 'macro-ins-K
   [?\C-[ ?! ?\323 ?\324 ?\305 ?\322 ?\305 ?\324 ?\330 ?  ?\306 ?\301 ?\312 ?\314 ?  ?\311 ?\314 ?\311 ?  ?\313 ?\301 ?\324 ?\301 ?\314 ?\317 ?\307 ?  ?\C-m])
(global-set-key [-134217637 112 insert ?K] 'macro-ins-K)
(global-set-key [-134217637 112 insertchar ?K] 'macro-ins-K)
(fset 'macro-ins-k
   [?\C-[ ?! ?\320 ?\305 ?\322 ?\305 ?\315 ?\305 ?\323 ?\324 ?\311 ?\324 ?\330 ?  ?\306 ?\301 ?\312 ?\314 ?  ?\311 ?\314 ?\311 ?  ?\313 ?\301 ?\324 ?\301 ?\314 ?\317 ?\307 ?  ?\327 ?  ?\313 ?\317 ?\322 ?\332 ?\311 ?\316 ?\325 ?  ?/ ?t ?m ?p ?/ ?m ?u ?s ?o ?r ?\C-m])
(global-set-key [-134217637 112 insertchar ?k] 'macro-ins-k)
(global-set-key [-134217637 112 insert ?k] 'macro-ins-k)

;;монтирование и размонтирование сидирома
(fset 'macro-mount-cdrom
   "\C-[xfind-file\C-m/home\C-m\C-[!.mc\C-m")
(global-set-key [insertchar ?m] 'macro-mount-cdrom)
(global-set-key [insert ?m] 'macro-mount-cdrom)
(fset 'macro-ins-m
   [?\C-[ ?! ?\320 ?\322 ?\311 ?\315 ?\317 ?\316 ?\324 ?\311 ?\322 ?\317 ?\327 ?\301 ?\324 ?\330 ?  ?\323 ?\311 ?\327 ?\C-? ?\304 ?\311 ?\322 ?\317 ?\315 ?\C-m])
(global-set-key [-134217637 112 insertchar ?m] 'macro-ins-m)
(global-set-key [-134217637 112 insert ?m] 'macro-ins-m)
;;монтирование и размонтирование дисковода
(fset 'macro-mount-floppy
   "\C-[xfind-file\C-m/home\C-m\C-[!.mf\C-m")
(global-set-key [insertchar ?f] 'macro-mount-floppy)
(global-set-key [insert ?f] 'macro-mount-floppy)
;;выключение системы
(fset 'macro-delete
   "\C-[xshell\C-m.shut\C-m")
(global-set-key [insertchar deletechar] 'macro-delete)
(global-set-key [insert delete] 'macro-delete)
(fset 'macro-ins-del
   [?\C-[ ?! ?\305 ?\323 ?\314 ?\311 ?  ?\316 ?\301 ?\326 ?\301 ?\324 ?\330 ?  ?\305 ?\335 ?\305 ?  ?\311 ?  ?\320 ?\322 ?\317 ?\302 ?\305 ?\314 ?  ?\324 ?\317 ?  ?\323 ?\311 ?\323 ?\324 ?\305 ?\315 ?\301 ?  ?\317 ?\323 ?\324 ?\301 ?\316 ?\317 ?\327 ?\311 ?\323 ?\C-? ?\324 ?\323 ?\321 ?\C-m])
(global-set-key [-134217637 112 insertchar deletechar] 'macro-ins-del)
(global-set-key [-134217637 112 insert deletechar] 'macro-ins-del)

;;создание url листа для wget
(fset 'macro-wgetlist
   [?u escape ?! ?e ?c ?h ?o ?  ?\C-y ?  ?> ?> ?/ ?h ?o ?m ?e ?/ ?w ?g ?e ?t ?l ?i ?s ?t return])
(global-set-key [f4 f2] 'macro-wgetlist)
(fset 'macro-f4-f2
   [?\C-[ ?! ?c ?\C-? ?\323 ?\317 ?\332 ?\304 ?\301 ?\316 ?\311 ?\305 ?  ?\325 ?\322 ?\314 ?  ?\314 ?\311 ?\323 ?\324 ?\301 ?  ?\304 ?\314 ?\321 ?  ?\320 ?\322 ?\317 ?\307 ?\322 ?\301 ?\315 ?\331 ?  ?w ?g ?e ?t ?\C-m])
(global-set-key [-134217637 112 f4 f2] 'macro-f4-f2)
;;прослушивание mp3 файла в интернете
(fset 'macro-internet-mp3
   [?u escape ?! ?m ?p ?l ?a ?y ?e ?r ?  ?\C-y return])
(global-set-key [f4 f1] 'macro-internet-mp3)
(fset 'macro-f4-f1
   [?\C-[ ?! ?\320 ?\322 ?\317 ?\323 ?\314 ?\325 ?\333 ?\311 ?\327 ?\301 ?\316 ?\311 ?\305 ?  ?\315 ?\320 ?3 ?  ?\306 ?\301 ?\312 ?\314 ?\301 ?  ?\327 ?  ?\311 ?\316 ?\324 ?\305 ?\322 ?\316 ?\305 ?\324 ?\305 ?\C-m])
(global-set-key [-134217637 112 f4 f1] 'macro-f4-f1)
(fset 'macro-search-w
   "\C-k\C-k\C-[xreplace-string\C-m\C-y\C-m\C-m\C-[[2~\C-[[4~\C-y\C-[[2~\C-[[1~")
(global-set-key [f4 ?z] 'macro-search-w)
;;убрать повторные строки в вгетлисте
(fset 'macro-f4-z
   [?\C-[ ?! ?\325 ?\302 ?\322 ?\301 ?\324 ?\330 ?  ?\304 ?\327 ?\317 ?\312 ?\316 ?\331 ?\305 ?  ?\323 ?\324 ?\322 ?\317 ?\313 ?\311 ?  ?\327 ?  ?\327 ?\307 ?\305 ?\324 ?\314 ?\311 ?\323 ?\324 ?\305 ?\C-m])
(global-set-key [-134217637 112 f4 122] 'macro-f4-z)
(fset 'macro-wget-mp3
   "\C-[[18~mp3\C-m\C-[[[D\C-[[[B")
(global-set-key [f4 ?x] 'macro-wget-mp3)
(fset 'macro-f4-x
   [?\C-[ ?! ?\323 ?\317 ?\323 ?\324 ?\301 ?\327 ?\311 ?\324 ?\330 ?  ?\327 ?\307 ?\305 ?\324 ?  ?\330 ?\C-? ?\315 ?\332 ?\C-? ?\320 ?3 ?\314 ?\333 ?\C-? ?\311 ?\331 ?\C-? ?\323 ?\324 ?\C-m])
(global-set-key [-134217637 112 f4 120] 'macro-f4-x)


;;получить почту
(fset 'macro-fetchmail
   "\C-[xshell\C-m.s\C-m")
(global-set-key [f4 f3] 'macro-fetchmail)
;;вызов почтовой программы
(global-set-key [f4 ?g] 'gnus)
;;запуск браузера w3m
(fset 'macro-w3m
   [?\M-x ?w ?3 ?m ?- ?f ?i ?n ?d ?- ?f ?i ?l ?e return ?/ ?m ?a ?s ?t ?e ?r ?/ ?p ?a ?g ?e ?. ?h ?t ?m ?l return])
(global-set-key [f4 f4] 'macro-w3m)
;;удаление ненужных писем
(fset 'macro-del-letter
   "B\C-?yes\C-m")
(global-set-key [f4 ?d] 'macro-del-letter)

(global-set-key [f11] 'bookmark-bmenu-list)
(fset 'macro-number-line
   "\C-xl\C-ea")
(global-set-key [insertchar f12] 'macro-number-line)
(global-set-key [insert f12] 'macro-number-line)
(fset 'macro-ins-f12
   [?\C-[ ?! ?\325 ?\332 ?\316 ?\301 ?\324 ?\330 ?  ?\323 ?\313 ?\317 ?\314 ?\330 ?\313 ?\317 ?  ?\323 ?\324 ?\322 ?\317 ?\313 ?  ?\327 ?  ?\302 ?\325 ?\306 ?\305 ?\322 ?\305 ?  ?\311 ?  ?\316 ?\301 ?  ?\313 ?\301 ?\313 ?\317 ?\312 ?  ?\316 ?\301 ?\310 ?\317 ?\304 ?\311 ?\324 ?\323 ?\321 ?  ?\313 ?\325 ?\322 ?\323 ?\317 ?\322 ?\C-m])
(global-set-key [-134217637 112 insertchar f12] 'macro-ins-f12)
(global-set-key [-134217637 112 insert f12] 'macro-ins-f12)
;;просмотр заголовка архивного файла без его распаковки
(fset 'macro-rar-view
   "w\C-[xshell\C-m.rxh \C-y\C-m")
(global-set-key [insertchar ?v] 'macro-rar-view)
(global-set-key [insert ?v] 'macro-rar-view)
;;распаковка книг
(fset 'macro-unz
   "w\C-[xshell\C-m.unz \"\C-y\"\C-m")
(global-set-key [insertchar ?u] 'macro-unz)
(global-set-key [insert ?u] 'macro-unz)
;;открыть html файл
(fset 'macro-w3m-op
   "w\C-[xw3m-find-file\C-m\C-y\C-m")
(global-set-key [insertchar ?w] 'macro-w3m-op)
(global-set-key [insert ?w] 'macro-w3m-op)
;;поставить закладку, закрыть буфер и ждать остановки системы
(fset 'macro-bookmark-halt
   "\C-[xbookmark-set\C-m\C-m\C-[xbookmark-save\C-m\C-[xsave-buffer\C-m\C-[xkill-buffer\C-m\C-m\C-xq\C-[xshell\C-mshutdown -h now\C-m")
(global-set-key [insertchar f11] 'macro-bookmark-halt)
(global-set-key [insert f11] 'macro-bookmark-halt)
;;записная книжка
(fset 'macro-baza
   "\C-[[[A.baza\C-m")
(global-set-key [insertchar f9] 'macro-baza)
(global-set-key [insert f9] 'macro-baza)
;;поиск в базе
(global-set-key [f7] 'search-forward)

;;музыкальные программы
(fset 'macro-music-help
   "\C-[xfind-file\C-m/etc/script/musichelp\C-m")
(global-set-key [f6 ?h] 'macro-music-help)
;;запись с микрофона
(fset 'macro-sox
   "w\C-[xshell\C-m.sox1 \"\C-y\"\C-m")
(global-set-key [f6 ?s] 'macro-sox)
;;настройка файла sox
(fset 'macro-sox-open
   "\C-[xfind-file\C-m/etc/script/.sox\C-m")

(global-set-key [f6 ?o] 'macro-sox-open)
;;просмотреть теги файла
(fset 'macro-mutagen
   "w\C-[xshell\C-mmutagen-inspect \"\C-y\"\C-m")
(global-set-key [insertchar ?i] 'macro-mutagen)
(global-set-key [insert ?i] 'macro-mutagen)
(fset 'macro-mplayer-fifo
   "!mplayer-control \C-m")
(global-set-key [f6 ?m] 'macro-mplayer-fifo)
;;запуск мплаера
(fset 'macro-mplayer
   "!mplayer \C-m")
(global-set-key [f6 ?g] 'macro-mplayer)
(fset 'macro-mplayer-edlout
   "!mplayer -edlout abc \C-m")
(global-set-key [f6 ?1] 'macro-mplayer-edlout)
(fset 'macro-metka
   [?\M-f ?\M-d ?\M-f ?\C-k ?  delete])
(global-set-key [f6 ?9] 'macro-metka)
(fset 'macro-abc
   [?\M-x ?f ?i ?n ?d ?- ?f ?i ?l ?e return ?a ?b ?c return ?\M-x ?b ?e ?g ?i ?n ?n ?i ?n ?g ?- ?o ?f ?- ?b ?u ?f ?f ?e ?r return ?\C-u?0 ?\M-x ?m ?a ?c ?r ?o ?- ?m ?e ?t ?k ?a return])
(global-set-key [f6 ?2] 'macro-abc)
(fset 'macro-split
   [?! ?. ?a ?s ?1 return])
(global-set-key [f6 ?3] 'macro-split)
;;вырезать звуковую дорожку из фильма
(fset 'macro-track
   "!.track\C-m")
(global-set-key [f6 ?4] 'macro-track)
;;воспроизвести mp3 файл под курсором
(fset 'macro-mpg
   "w\C-[!mpg123 \"\C-y\" &\C-m")
(global-set-key [f6 f1] 'macro-mpg)
(fset 'macro-f6-f1
   [?\C-[ ?! ?\327 ?\317 ?\323 ?\320 ?\322 ?\317 ?\311 ?\332 ?\327 ?\305 ?\323 ?\324 ?\311 ?  ?m ?p ?3 ?  ?\306 ?\301 ?\312 ?\314 ?  ?\320 ?\317 ?\304 ?  ?\313 ?\325 ?\322 ?\323 ?\317 ?\322 ?\317 ?\315 ?\C-m])
(global-set-key [134217819 112 f6 f1] 'macro-f6-f1)
;;переход на следующий mp3 трек
(fset 'macro-mpg-mpg
   "\C-[[Bw\C-[!killall mpg123 ;mpg123 \"\C-y\" &\C-myes\C-m")
(global-set-key [f6 f2] 'macro-mpg-mpg)
(fset 'macrof6-f2
   [?\C-[ ?! ?\320 ?\305 ?\322 ?\305 ?\312 ?\324 ?\311 ?  ?\316 ?\301 ?  ?\323 ?\314 ?\305 ?\304 ?\325 ?\300 ?\335 ?\311 ?\312 ?  ?m ?p ?3 ?  ?\324 ?\322 ?\305 ?\313 ?\C-m])
(global-set-key [134217819 112 f6 f2] 'macro-f6-f2)
;;убить файл под курсором
(fset 'macro-rm
   "\C-[!rm \"\C-y\"\C-m")
(global-set-key [f6 f3] 'macro-rm)
;;убить mpg123 процесс
(fset 'macro-killmpg
   "\C-[!killall mpg123\C-m")
(global-set-key [f6 f4] 'macro-killmpg)
(fset 'macro-f6-f4
   [?\C-[ ?! ?\325 ?\302 ?\311 ?\324 ?\330 ?  ?m ?p ?g ?1 ?2 ?3 ?  ?\320 ?\322 ?\317 ?\303 ?\305 ?\323 ?\323 ?\C-m])
(global-set-key [134217819 112 f6 f4] 'macro-f6-f4)
;;internetradio
(fset 'macro-sound
   "\C-[xshell\C-m.101\C-m")
(global-set-key [f6 f5] 'macro-sound)
;;запуск mpc плеера
;;(fset 'macro-mpc
;;   "w\C-[xshell\C-m.menu \"\C-y\"\C-m")
;;(global-set-key [f6 f8] 'macro-mpc)
(global-set-key [f6 ?q] (lambda () (interactive) (shell-command-to-string "mplayerQuit") ))
(global-set-key [f6 ?f] (lambda () (interactive) (shell-command-to-string "mplayerForward") ))
(global-set-key [f6 ?n] (lambda () (interactive) (shell-command-to-string "mplayerNext") ))
(global-set-key [f6 ?p] (lambda () (interactive) (shell-command-to-string "mplayerPlay") ))
;;запуск mp3 плеера
(fset 'macro-mpg-123
   "w\C-[!echo `pwd \C-y`/\C-y >/etc/script/musor\C-m\C-[xfind-file\C-m/etc/script/musor\C-m\C-[xbeginning-of-buffer\C-m\C-k\C-[xsave-buffer\C-m\C-[xkill-buffer\C-m\C-m\C-[xmpg123\C-m/\C-y\C-m ")
(global-set-key [f6 f7] 'macro-mpg-123)
;;запуск интернетрадио
(fset 'macro-radio
   "w\C-[xshell\C-m.r \"\C-y\"\C-m")
(global-set-key [f6 ?r] 'macro-radio)
;;запуск телевиденья
(fset 'macro-tele
   "w\C-[xshell\C-m.tel \"\C-y\"\C-m")
(global-set-key [f6 ?t] 'macro-tele)
;;меню программ записи на cdrom,dvd,cd
(fset 'macro-menu1
   "\C-[xshell\C-m.menu1\C-m")
(global-set-key [f10] 'macro-menu1)

;;разные программы
;;отключение и включение синтезатора
(fset 'macro-sintez
   "\C-u\C-edq")
(global-set-key [f6 f6] 'macro-sintez)
;;размер каталога или файла
(fset 'macro-size
   "z\C-ea")
(global-set-key [insertchar 122] 'macro-size)
(global-set-key [insert 122] 'macro-size)
(fset 'macro-ins-z
   [?\C-[ ?! ?\325 ?\332 ?\316 ?\301 ?\324 ?\330 ?  ?\322 ?\301 ?\332 ?\315 ?\305 ?\322 ?  ?\306 ?\301 ?\312 ?\314 ?\301 ?  ?\311 ?\314 ?\311 ?  ?\313 ?\301 ?\324 ?\301 ?\314 ?\317 ?\307 ?\301 ?\C-m])
(global-set-key [-134217637 112 insertchar ?z] 'macro-ins-z)
(global-set-key [-134217637 112 insert ?z] 'macro-ins-z)
(fset 'macro-time-wav
   [home tab tab tab tab tab ?\C-  tab ?\M-w f1 ?. ?s ?s ?  ?\C-y])
(global-set-key [f6 ?z] 'macro-time-wav)
(fset 'macro-zvon
   "\C-[xmpg123\C-m/etc/script/zvon.mp3\C-m")
(global-set-key [insertchar next] 'macro-zvon)
(global-set-key [insert next] 'macro-zvon)



(dired "/home")


